#
# spec file for package ghc-haddock-library
#
# Copyright (c) 2020 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name haddock-library
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.9.0
Release:        lp152.1.2
Summary:        Library exposing some functionality of Haddock
License:        BSD-2-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-transformers-devel
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-base-compat-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-optparse-applicative-devel
BuildRequires:  ghc-tree-diff-devel
%endif

%description
Haddock is a documentation-generation tool for Haskell libraries.
These modules expose some functionality of it without pulling in the GHC
dependency. Please note that the API is likely to change so be sure to specify
upper bounds in your projects. For interacting with Haddock itself, see the
[haddock package](https://hackage.haskell.org/package/haddock).

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGES.md

%changelog
* Wed May  6 2020 psimons@suse.com
- Update haddock-library to version 1.9.0.
  [#]# Changes in version 1.9.0
  * Fix build-time regression for `base < 4.7` (#1119)
  * Update parsing to strip whitespace from table cells (#1074)
* Mon Dec 23 2019 psimons@suse.com
- Update haddock-library to version 1.8.0.
  [#]# Changes in version 1.8.0
  * Support inline markup in markdown-style links (#875)
  * Remove now unused `Documentation.Haddock.Utf8` module.
    This module was anyways copied from the `utf8-string` package.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Wed Oct 17 2018 psimons@suse.com
- Update haddock-library to version 1.7.0.
  [#]# Changes in version 1.7.0
  * Make `Documentation.Haddock.Parser.Monad` an internal module
  [#]# Changes in version 1.6.1
  * Replace `attoparsec` with `parsec` (#799)
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Tue Jul 17 2018 psimons@suse.com
- Update haddock-library to version 1.6.0.
  [#]# Changes in version 1.6.0
  * `MetaDoc` stores package name for since annotations
* Mon May 14 2018 psimons@suse.com
- Update haddock-library to version 1.5.0.1.
  * Support for parsing unicode operators (#458)
  * Bifunctor, Bifoldable and Bitraversable instances for DocH and MetaDoc
  * Support for grid tables
  * added `DocTable` constructor to `DocH`
  * added `Table`, `TableCell` and `TableRow` data types
  * added `markupTable` to `DocMarkupH` data type
  * Move markup related data types to haddock-library
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Wed Apr 19 2017 psimons@suse.com
- Update to version 1.4.3 with cabal2obs.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 1.4.2 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 1.2.1 revision 0 with cabal2obs.
* Fri Aug  7 2015 mimi.vx@gmail.com
- update to 1.2.1
* Tue May 12 2015 mimi.vx@gmail.com
- update to 1.2.0
  * no upstream changelog
* Mon Apr 20 2015 mimi.vx@gmail.com
- remove unneeded dep
* Tue Feb  3 2015 mimi.vx@gmail.com
- initial commit of haddoc-library package
